@@ -132,7 +132,8 @@ class ImageClassificationExplainer:
                 n_steps=self.n_steps_noise_tunnel,
             )
 
-        return self.attributions.cpu().detach().numpy()
+        self.attributions = self.attributions.cpu().detach().numpy()
+        return self.attributions
 
     @staticmethod
     def _get_id2label_and_label2id_dict(
